b2luigi.basf2\_helper package
=============================

b2luigi.basf2\_helper.data module
---------------------------------

.. automodule:: b2luigi.basf2_helper.data
    :members:
    :undoc-members:
    :show-inheritance:

b2luigi.basf2\_helper.targets module
------------------------------------

.. automodule:: b2luigi.basf2_helper.targets
    :members:
    :undoc-members:
    :show-inheritance:

b2luigi.basf2\_helper.tasks module
----------------------------------

.. automodule:: b2luigi.basf2_helper.tasks
    :members:
    :undoc-members:
    :show-inheritance:

b2luigi.basf2\_helper.utils module
----------------------------------

.. automodule:: b2luigi.basf2_helper.utils
    :members:
    :undoc-members:
    :show-inheritance:
